import { Directive, ElementRef, Input, NgModule } from '@angular/core';
import { use, init } from 'echarts/core';
import { CanvasRenderer } from 'echarts/renderers';
import { interval } from 'rxjs';
import { filter, map } from 'rxjs/operators';

class HtmlHelper {
    static elementIsFocusable(ele) {
        return ele.getAttribute("tabindex") != null;
    }
    static getWidthSensor(element, periodicityInMiliSeconds = 2000) {
        let oldWidth = element.clientWidth;
        return interval(periodicityInMiliSeconds).pipe(filter(ignore => {
            if (Math.abs(oldWidth - element.clientWidth) > 2) {
                oldWidth = element.clientWidth;
                return true;
            }
            return false;
        }), map(ignore => element.clientWidth));
    }
    static getHeightSensor(element, periodicityInMiliSeconds = 2000) {
        let oldHeight = element.clientHeight;
        return interval(periodicityInMiliSeconds).pipe(filter(ignore => {
            if (Math.abs(oldHeight - element.clientHeight) > 2) {
                oldHeight = element.clientHeight;
                return true;
            }
            return false;
        }), map(ignore => element.clientWidth));
    }
}

class EchartsDirective {
    constructor(_el) {
        this._el = _el;
        this.extentions = [];
    }
    ngOnInit() {
        use([...this.extentions, CanvasRenderer]);
        this._echartsInstance = init(this._el.nativeElement, '', {
            width: this._el.nativeElement.clientWidth === 0 ? 400 : this._el.nativeElement.clientWidth,
            height: this._el.nativeElement.clientHeight === 0 ? 400 : this._el.nativeElement.clientHeight
        });
        this._setParams();
        this._subscription = HtmlHelper.getWidthSensor(this._el.nativeElement).subscribe(() => {
            if (this._echartsInstance != null) {
                this._echartsInstance.resize();
            }
        });
    }
    ngOnChanges(changes) {
        if (changes._options && !changes._options.firstChange) {
            this._setParams();
        }
    }
    _setParams() {
        if (this._echartsInstance != null && this.options != null)
            this._echartsInstance.setOption(Object.assign({}, this.options));
    }
    ngOnDestroy() {
        if (this._subscription != null)
            this._subscription.unsubscribe();
    }
}
EchartsDirective.decorators = [
    { type: Directive, args: [{
                selector: "[echarts]"
            },] }
];
EchartsDirective.ctorParameters = () => [
    { type: ElementRef }
];
EchartsDirective.propDecorators = {
    options: [{ type: Input }],
    extentions: [{ type: Input }]
};

class EchartsxModule {
}
EchartsxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EchartsDirective],
                exports: [EchartsDirective]
            },] }
];

/*
 * Public API Surface of echartsx
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EchartsxModule, EchartsDirective as ɵa };
//# sourceMappingURL=echarts-for-angular.js.map
